@@ -376,7 +376,7 @@ void read_headers( FILE *fp )
 /*********************************************************
 ** find string in string - ignore case **/
 
-char *strcasestr_ar( char *_s1, char *_s2 )
+char *strcasestr( char *_s1, char *_s2 )
 {
 	char *s1;
 	char *s2;
@@ -419,7 +419,7 @@ char *inspect_headers( char * tag, char *ss )
 			if ( ss == (char *)NULL )
 				return act_header->content;
 
-			if ( strcasestr_ar( act_header->content, ss ) != (char *)NULL )
+			if ( strcasestr( act_header->content, ss ) != (char *)NULL )
 				return act_header->content;
 
 			return (char *)NULL;
@@ -440,7 +440,7 @@ char *get_content_boundary()
 	if ( (s = inspect_headers( "Content-Type", (char *)NULL )) == (char *)NULL) 
 		return (char *)NULL;
 
-	if ( (r = strcasestr_ar( s, "boundary=" )) == (char *)NULL)
+	if ( (r = strcasestr( s, "boundary=" )) == (char *)NULL)
 		return (char *)NULL;
 	
 	*(r+strlen(r)-2) = '\0'; /* delete quote at the end */
@@ -621,16 +621,16 @@ char *TheDomain;
 
 	/*don't autorespond to a mailer-daemon*/
 	if( sender[0]==0 || strncasecmp(sender,"mailer-daemon",13)==0 || strchr(sender,'@')==NULL || strcmp(sender,"#@[]")==0 ) {
-		/*exit with success but request to stop parsing .qmail file*/
+		/*exit with success and continue parsing .qmail file*/
 		fprintf(stderr,"AUTORESPOND:  Stopping on mail from [%s].\n",sender);
-		_exit(99);
+		_exit(0);
 	}
 
 
 	if ( inspect_headers("mailing-list", (char *)NULL ) != (char *)NULL )
 	{
-		fprintf(stderr,"AUTORESPOND: I can't handle a message with a Mailing-List header.\n");
-		_exit(100);			/*hard error*/
+		fprintf(stderr,"AUTORESPOND: This looks like it's from a mailing list, I will ignore it.\n");
+		_exit(0);			/*report success and exit*/
 	}
 	if ( inspect_headers("Delivered-To", "Autoresponder" ) != (char *)NULL )
 	{
@@ -643,7 +643,7 @@ char *TheDomain;
 	     inspect_headers("precedence", "list" ) != (char *)NULL )
 	{
 		fprintf(stderr,"AUTORESPOND: Junk mail received.\n");
-		_exit(100);
+		_exit(0); /* don't reply to bulk, junk, or list mail */
 	}
 
 	/*check the logs*/
@@ -694,7 +694,7 @@ char *TheDomain;
 	}
 	if(count>num) {
 		fprintf(stderr,"AUTORESPOND: too many received from [%s]\n",sender);
-		_exit(99);
+		_exit(0); /* don't reply to this message, but allow it to be delivered */
 	}
 
 	sprintf(filename,"tmp%u.%u",getpid(),timer);
